from setuptools import setup

with open("README.md", "r") as fh:
    long_description = fh.read()

setup(
    name="avinash-ai",
    version="2.0.1",
    description="Build your own ML",
    packages=["avinash-ai"],
    install_requires=["openai"],
    long_description=long_description,
    long_description_content_type="text/markdown",
)




import os
import openai

openai.api_key = os.getenv("OPENAI_API_KEY")

# write a function to capture response from openai
def analyze_your_query(prompt):
    response = openai.Completion.create(
        model="text-davinci-003",
        prompt=prompt,
        temperature=0.7,
        max_tokens=256,
        top_p=1,
        frequency_penalty=0,
        presence_penalty=0
        )
    return response.choices[0].text

